@@ -26,6 +26,11 @@
 
 from __future__ import unicode_literals
 
+# Python 3.10+ removed a bunch of aliases from the collections module.
+# Unfortunately, Django 1.11 and nose still rely on these. Do this before
+# anything else.
+import djblets.util.compat.python.collections
+
 
 # The version of Djblets
 #
@@ -33,7 +38,7 @@ from __future__ import unicode_literals
 #
 #   (Major, Minor, Micro, alpha/beta/rc/final, Release Number, Released)
 #
-VERSION = (2, 2, 3, 'final', 0, True)
+VERSION = (2, 3, 0, 'final', 0, True)
 
 
 def get_version_string():
