@@ -287,7 +287,8 @@ class ExtensionManager(object):
         self._extension_list_url = None
 
         # Extension middleware instances, ordered by dependencies.
-        self.middleware = []
+        self.middleware_classes = []
+        self.legacy_middleware_instances = []
 
         # Wrap the INSTALLED_APPS and TEMPLATE_CONTEXT_PROCESSORS settings
         # to allow for ref-counted add/remove operations.
@@ -583,6 +584,7 @@ class ExtensionManager(object):
 
             registration = extension.registration
         else:
+            extension = None
             del self._load_errors[extension_id]
 
             if extension_id in self._extension_classes:
@@ -601,7 +603,9 @@ class ExtensionManager(object):
         self._bump_sync_gen()
         self._recalculate_middleware()
 
-        extension_disabled.send_robust(sender=self, extension=extension)
+        if extension is not None:
+            extension_disabled.send_robust(sender=self,
+                                           extension=extension)
 
     def install_extension(self, install_url, package_name):
         """Install an extension from a remote source.
@@ -1641,11 +1645,14 @@ class ExtensionManager(object):
         All middleware provided by extensions will be registered in the
         Django settings and will be used for future requests.
         """
-        self.middleware = []
+        self.middleware_classes = []
+        self.legacy_middleware_instances = []
         done = set()
 
         for e in self.get_enabled_extensions():
-            self.middleware.extend(self._get_extension_middleware(e, done))
+            mw, legacy_mw = self._get_extension_middleware(e, done)
+            self.middleware_classes += mw
+            self.legacy_middleware_instances += legacy_mw
 
     def _get_extension_middleware(self, extension, done):
         """Return a list of middleware for an extension and its dependencies.
@@ -1664,10 +1671,13 @@ class ExtensionManager(object):
                 found that exist in this set will be ignored.
 
         Returns:
-            list of type:
-            The list of middleware classes for the extension.
+            tuple of list:
+            A 2-tuple of lists. The first list is a list of classes for
+            new-style (Django 1.10+) middleware. The second list is a list of
+            instances for old-style middleware.
         """
         middleware = []
+        legacy_middleware = []
 
         if extension in done:
             return middleware
@@ -1678,10 +1688,13 @@ class ExtensionManager(object):
             e = self.get_enabled_extension(req)
 
             if e:
-                middleware.extend(self._get_extension_middleware(e, done))
+                mw, legacy_mw = self._get_extension_middleware(e, done)
+                middleware += mw
+                legacy_middleware += legacy_mw
 
-        middleware.extend(extension.middleware_instances)
-        return middleware
+        middleware.extend(extension.middleware_classes)
+        legacy_middleware.extend(extension.legacy_middleware_instances)
+        return middleware, legacy_middleware
 
     @contextmanager
     def _open_lock_file(self, ext_class, filename,
