@@ -2,14 +2,15 @@ from __future__ import unicode_literals
 
 import json
 
-from django.core.management.base import NoArgsCommand
+from django.core.management.base import BaseCommand
 
 from djblets.siteconfig.models import SiteConfiguration
 
 
-class Command(NoArgsCommand):
+class Command(BaseCommand):
     """Lists the site configuration."""
-    def handle_noargs(self, **options):
+
+    def handle(self, *args, **options):
         siteconfig = SiteConfiguration.objects.get_current()
 
         self.stdout.write(json.dumps(siteconfig.settings, indent=2))
